#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-5N5f57r52kuB9FBoK1QZlo
key:                  hspec-expectations-lifted-0.10.0-5N5f57r52kuB9FBoK1QZlo
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  83467085cefe7c8037eee79eddb9a59d
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hspec-expectations-lifted-0.10.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-5N5f57r52kuB9FBoK1QZlo
depends:
    base-4.18.2.1 hspec-expectations-0.8.4-Ljshn9rnpijIIHPFCAErse
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

